@@ -44,10 +44,10 @@ class Schedule(xuexitong.Xuexitong):
         print("已经被预约的座位号",reservdSeats)
 
         for seat in seats.get("seats"):
-            if seat not in reservdSeats and seat not result:
+            if seat not in reservdSeats and seat not in result:
                 data["seatNum"] = seat
                 
-                result.append( data )
+                result.append( data.copy() )
 
         print("符合需求的座位号",result,"\n")
 
